@@ -147,69 +147,6 @@ $(function() {
 });
 
 },{}],3:[function(require,module,exports){
-window.filterTags = {
-  bind: function() {
-    var options = {
-      valueNames: [{ data: ["tags"] }],
-      page: "6",
-      pagination: true
-    };
-
-    var tutorialList = new List("tutorial-cards", options);
-
-    function filterSelectedTags(cardTags, selectedTags) {
-      return cardTags.some(function(tag) {
-        return selectedTags.some(function(selectedTag) {
-          return selectedTag == tag;
-        });
-      });
-    }
-
-    function updateList() {
-      var selectedTags = [];
-
-      $(".selected").each(function() {
-        selectedTags.push($(this).data("tag"));
-      });
-
-      tutorialList.filter(function(item) {
-        var cardTags;
-
-        if (item.values().tags == null) {
-          cardTags = [""];
-        } else {
-          cardTags = item.values().tags.split(",");
-        }
-
-        if (selectedTags.length == 0) {
-          return true;
-        } else {
-          return filterSelectedTags(cardTags, selectedTags);
-        }
-      });
-    }
-
-    $(".filter-btn").on("click", function() {
-      if ($(this).data("tag") == "all") {
-        $(this).addClass("all-tag-selected");
-        $(".filter").removeClass("selected");
-      } else {
-        $(this).toggleClass("selected");
-        $("[data-tag='all']").removeClass("all-tag-selected");
-      }
-
-      // If no tags are selected then highlight the 'All' tag
-
-      if (!$(".selected")[0]) {
-        $("[data-tag='all']").addClass("all-tag-selected");
-      }
-
-      updateList();
-    });
-  }
-};
-
-},{}],4:[function(require,module,exports){
 // Modified from https://stackoverflow.com/a/32396543
 window.highlightNavigation = {
   navigationListItems: document.querySelectorAll("#sphinx-template-right-menu li"),
@@ -282,13 +219,9 @@ window.highlightNavigation = {
   }
 };
 
-},{}],5:[function(require,module,exports){
+},{}],4:[function(require,module,exports){
 window.mainMenuDropdown = {
   bind: function() {
-    $("[data-toggle='ecosystem-dropdown']").on("click", function() {
-      toggleDropdown($(this).attr("data-toggle"));
-    });
-
     $("[data-toggle='resources-dropdown']").on("click", function() {
       toggleDropdown($(this).attr("data-toggle"));
     });
@@ -309,7 +242,7 @@ window.mainMenuDropdown = {
   }
 };
 
-},{}],6:[function(require,module,exports){
+},{}],5:[function(require,module,exports){
 window.mobileMenu = {
   bind: function() {
     $("[data-behavior='open-mobile-menu']").on('click', function(e) {
@@ -341,7 +274,7 @@ window.mobileMenu = {
   }
 };
 
-},{}],7:[function(require,module,exports){
+},{}],6:[function(require,module,exports){
 window.mobileTOC = {
   bind: function() {
     $("[data-behavior='toggle-table-of-contents']").on("click", function(e) {
@@ -362,8 +295,8 @@ window.mobileTOC = {
   }
 }
 
-},{}],8:[function(require,module,exports){
-window.pytorchAnchors = {
+},{}],7:[function(require,module,exports){
+window.trojanzooAnchors = {
   bind: function() {
     // Replace Sphinx-generated anchors with anchorjs ones
     $(".headerlink").text("");
@@ -382,7 +315,7 @@ window.pytorchAnchors = {
   }
 };
 
-},{}],9:[function(require,module,exports){
+},{}],8:[function(require,module,exports){
 // Modified from https://stackoverflow.com/a/13067009
 // Going for a JS solution to scrolling to an anchor so we can benefit from
 // less hacky css and smooth scrolling.
@@ -483,7 +416,7 @@ window.scrollToAnchor = {
   }
 };
 
-},{}],10:[function(require,module,exports){
+},{}],9:[function(require,module,exports){
 window.sideMenus = {
   rightMenuIsOnScreen: function() {
     return document.getElementById("sphinx-template-content-right").offsetParent !== null;
@@ -558,6 +491,7 @@ window.sideMenus = {
           linkWithHash.nextElementSibling.children.length > 0
         ) {
           linkWithHash.nextElementSibling.style.display = "block";
+          linkWithHash.classList.remove("not-expanded");
           linkWithHash.classList.add("expanded");
         }
 
@@ -566,7 +500,7 @@ window.sideMenus = {
       }
 
       // Bind click events on right menu links
-      $("#sphinx-template-right-menu a.reference.internal").on("click", function() {
+      $('#sphinx-template-right-menu').on('click', 'a.reference.internal', function() {
         if (this.classList.contains("expanded")) {
           this.nextElementSibling.style.display = "none";
           this.classList.remove("expanded");
@@ -634,7 +568,7 @@ window.sideMenus = {
 
   handleLeftMenu: function () {
     var windowHeight = utilities.windowHeight();
-    var topOfFooterRelativeToWindow = document.getElementById("docs-tutorials-resources").getBoundingClientRect().top;
+    var topOfFooterRelativeToWindow = document.getElementById("docs-resources").getBoundingClientRect().top;
 
     if (topOfFooterRelativeToWindow >= windowHeight) {
       document.getElementById("sphinx-template-left-menu").style.height = "100%";
@@ -669,12 +603,14 @@ window.sideMenus = {
           rightMenu.style.top = utilities.scrollTop() - mainHeaderHeight + "px";
           rightMenu.classList.add("scrolling-absolute");
           rightMenu.classList.remove("scrolling-fixed");
+          document.getElementById("sphinx-template-shortcuts-wrapper").style.display = "none";
         }
       } else {
         rightMenuWrapper.style.height = articleHeight + mainHeaderHeight + "px";
         rightMenu.style.top =
           articleBottom - mainHeaderHeight - rightMenuList.offsetHeight + "px";
         rightMenu.classList.add("scrolling-absolute");
+        document.getElementById("sphinx-template-shortcuts-wrapper").style.display = "none";
       }
 
       if (utilities.scrollTop() < articleBottom - rightMenuList.offsetHeight) {
@@ -682,6 +618,7 @@ window.sideMenus = {
         rightMenu.style.top = "";
         rightMenu.classList.remove("scrolling-absolute");
         rightMenu.classList.add("scrolling-fixed");
+        document.getElementById("sphinx-template-shortcuts-wrapper").style.display = "block";
       }
     }
 
@@ -775,7 +712,7 @@ function ThemeNav () {
         $(document)
             // Shift nav in mobile when clicking the menu.
             .on('click', "[data-toggle='sphinx-template-left-menu-nav-top']", function() {
-                $("[data-toggle='wy-nav-shift']").toggleClass("shift");
+                $("[data-toggle='sphinx-template-nav-shift']").toggleClass("shift");
                 $("[data-toggle='rst-versions']").toggleClass("shift");
             })
 
@@ -783,7 +720,7 @@ function ThemeNav () {
             .on('click', ".sphinx-template-menu-vertical .current ul li a", function() {
                 var target = $(this);
                 // Close menu when you click a link.
-                $("[data-toggle='wy-nav-shift']").removeClass("shift");
+                $("[data-toggle='sphinx-template-nav-shift']").removeClass("shift");
                 $("[data-toggle='rst-versions']").toggleClass("shift");
                 // Handle dynamic display of l3 and l4 nav lists
                 self.toggleCurrent(target);
@@ -795,19 +732,19 @@ function ThemeNav () {
 
         // Make tables responsive
         $("table.docutils:not(.field-list,.footnote,.citation)")
-            .wrap("<div class='wy-table-responsive'></div>");
+            .wrap("<div class='sphinx-template-table-responsive'></div>");
 
         // Add extra class to responsive tables that contain
         // footnotes or citations so that we can target them for styling
         $("table.docutils.footnote")
-            .wrap("<div class='wy-table-responsive footnote'></div>");
+            .wrap("<div class='sphinx-template-table-responsive footnote'></div>");
         $("table.docutils.citation")
-            .wrap("<div class='wy-table-responsive citation'></div>");
+            .wrap("<div class='sphinx-template-table-responsive citation'></div>");
 
         // Add expand links to all parents of nested ul
         $('.sphinx-template-menu-vertical ul').not('.simple').siblings('a').each(function () {
             var link = $(this);
-                expand = $('<span class="toctree-expand"></span>');
+            expand = $('<span class="toctree-expand"></span>');
             expand.on('click', function (ev) {
                 self.toggleCurrent(link);
                 ev.stopPropagation();
@@ -839,14 +776,24 @@ function ThemeNav () {
             // If we found a matching link then reset current and re-apply
             // otherwise retain the existing match
             if (link.length > 0) {
-                $('.sphinx-template-menu-vertical .current').removeClass('current');
-                link.addClass('current');
-                link.closest('li.toctree-l1').parent().addClass('current');
-                link.closest('li.toctree-l1').addClass('current');
-                link.closest('li.toctree-l2').addClass('current');
-                link.closest('li.toctree-l3').addClass('current');
-                link.closest('li.toctree-l4').addClass('current');
+                $('.sphinx-template-menu-vertical .current')
+                    .removeClass('current')
+                    .attr('aria-expanded','false');
+                link.addClass('current')
+                    .attr('aria-expanded','true');
+                link.closest('li.toctree-l1')
+                    .parent()
+                    .addClass('current')
+                    .attr('aria-expanded','true');
+                for (let i = 1; i <= 10; i++) {
+                    link.closest('li.toctree-l' + i)
+                        .addClass('current')
+                        .attr('aria-expanded','true');
+                }
+                link[0].scrollIntoView();
             }
+            $('.sphinx-template-menu-vertical li.toctree-l1')
+                .attr('aria-expanded','true');
         }
         catch (err) {
             console.log("Error expanding nav for anchor", err);
@@ -882,10 +829,27 @@ function ThemeNav () {
 
     nav.toggleCurrent = function (elem) {
         var parent_li = elem.closest('li');
-        parent_li.siblings('li.current').removeClass('current');
-        parent_li.siblings().find('li.current').removeClass('current');
-        parent_li.find('> ul li.current').removeClass('current');
-        parent_li.toggleClass('current', true);
+        parent_li
+            .siblings('li.current')
+            .removeClass('current')
+            .attr('aria-expanded','false');
+        parent_li
+            .siblings()
+            .find('li.current')
+            .removeClass('current')
+            .attr('aria-expanded','false');
+        var children = parent_li.find('> ul li');
+        // Don't toggle terminal elements.
+        if (children.length) {
+            children
+                .removeClass('current')
+                .attr('aria-expanded','false');
+        }
+        parent_li
+            .toggleClass('current')
+            .attr('aria-expanded', function(i, old) {
+                return old == 'true' ? 'false' : 'true';
+            });
     }
 
     return nav;
@@ -936,27 +900,7 @@ if (typeof(window) != 'undefined') {
 $(".sphx-glr-thumbcontainer").removeAttr("tooltip");
 $("table").removeAttr("border");
 
-// This code replaces the default sphinx gallery download buttons
-// with the 3 download buttons at the top of the page
-
-var downloadNote = $(".sphx-glr-download-link-note.admonition.note");
-if (downloadNote.length >= 1) {
-    var tutorialUrlArray = $("#tutorial-type").text().split('/');
-        tutorialUrlArray[0] = tutorialUrlArray[0] + "_source"
-
-    var githubLink = "https://github.com/pytorch/tutorials/blob/master/" + tutorialUrlArray.join("/") + ".py",
-        notebookLink = $(".reference.download")[1].href,
-        notebookDownloadPath = notebookLink.split('_downloads')[1],
-        colabLink = "https://colab.research.google.com/github/pytorch/tutorials/blob/gh-pages/_downloads" + notebookDownloadPath;
-
-    $("#google-colab-link").wrap("<a href=" + colabLink + " data-behavior='call-to-action-event' data-response='Run in Google Colab' target='_blank'/>");
-    $("#download-notebook-link").wrap("<a href=" + notebookLink + " data-behavior='call-to-action-event' data-response='Download Notebook'/>");
-    $("#github-view-link").wrap("<a href=" + githubLink + " data-behavior='call-to-action-event' data-response='View on Github' target='_blank'/>");
-} else {
-    $(".sphinx-template-call-to-action-links").hide();
-}
-
-//This code handles the Expand/Hide toggle for the Docs/Tutorials left nav items
+//This code handles the Expand/Hide toggle for the Docs left nav items
 
 $(document).ready(function() {
   var caption = "#sphinx-template-left-menu p.caption";
@@ -1001,57 +945,6 @@ $(document).ready(function() {
   }
 });
 
-// Build an array from each tag that's present
-
-var tagList = $(".tutorials-card-container").map(function() {
-    return $(this).data("tags").split(",").map(function(item) {
-        return item.trim();
-      });
-}).get();
-
-function unique(value, index, self) {
-      return self.indexOf(value) == index && value != ""
-    }
-
-// Only return unique tags
-
-var tags = tagList.sort().filter(unique);
-
-// Add filter buttons to the top of the page for each tag
-
-function createTagMenu() {
-    tags.forEach(function(item){
-    $(".tutorial-filter-menu").append(" <div class='tutorial-filter filter-btn filter' data-tag='" + item + "'>" + item + "</div>")
-  })
-};
-
-createTagMenu();
-
-// Remove hyphens if they are present in the filter buttons
-
-$(".tags").each(function(){
-    var tags = $(this).text().split(",");
-    tags.forEach(function(tag, i ) {
-       tags[i] = tags[i].replace(/-/, ' ')
-    })
-    $(this).html(tags.join(", "));
-});
-
-// Remove hyphens if they are present in the card body
-
-$(".tutorial-filter").each(function(){
-    var tag = $(this).text();
-    $(this).html(tag.replace(/-/, ' '))
-})
-
-// Remove any empty p tags that Sphinx adds
-
-$("#tutorial-cards p").each(function(index, item) {
-    if(!$(item).text().trim()) {
-        $(item).remove();
-    }
-});
-
 // Jump back to top on pagination click
 
 $(document).on("click", ".page", function() {
@@ -1084,8 +977,8 @@ $(".stars-outer > i").on("click", function() {
     });
 })
 
-$("#sphinx-template-side-scroll-right li a").on("click", function (e) {
-  var href = $(this).attr("href");
+$("#sphinx-template-side-scroll-right").on("click", "a.reference.internal", function (e) {
+  var href = $(this).attr("href").replaceAll('.', '\\.');
   $('html, body').stop().animate({
     scrollTop: $(href).offset().top - 100
   }, 850);
@@ -1123,4 +1016,4 @@ $(window).scroll(function () {
   });
 });
 
-},{"jquery":"jquery"}]},{},[1,2,3,4,5,6,7,8,9,10,"sphinx-template-sphinx-theme"]);
+},{"jquery":"jquery"}]},{},[1,2,3,4,5,6,7,8,9,"sphinx-template-sphinx-theme"]);
